Crate mpc_ristretto

Crate mpc_ristretto 

Modules

authenticated_ristretto
Groups logic for a Ristretto Point that contains an authenticated value
authenticated_scalar
Implements an authenticated wrapper around the MpcScalar type for malicious security
beaver
Defines the Beaver value generation interface as well as a dummy beaver interface for testing
commitment
Pedersen commitment implementation, borrowed from https://github.com/dalek-cryptography/bulletproofs/blob/main/src/generators.rs#L29
error
Errors defined across the MPC implementation
fabric
Defines an MPC fabric for the protocol
mpc_ristretto
Groups the definitions and trait implementations for a Ristretto point within the MPC net
mpc_scalar
Groups the definitions and trait implementations for a scalar value within an MPC network
network
The network module defines abstractions of the transport used to communicate during the course of an MPC

Enums

Visibility
Visibility determines what information peers have for values allocated in the network.

Traits

Visible
A wrapper trait that allows for implementing generic comparisons

Type Aliases

BeaverSource
SharedNetwork
SharedNetwork wraps a network implementation in a borrow-safe container while providing interior mutability